# lc7001
Legrand LC7001 Python interface.

See [cli.py](cli.py) for a demonstration of the [lc7001.aio](lc7001/aio.py) module usage. 

See also
* [Legrand/On-Q LC7001 Whole House Lighting Controller](https://www.legrand.us/wiring-devices/electrical-accessories/miscellaneous/adorne-hub/p/lc7001)
* [LC7001 on Amazon](https://www.amazon.com/Legrand-Q-LC7001-Lighting-Controller/dp/B06XW1MLVF)
* [Legrand Radio Frequency Lighting Control (RFLC)](https://www.legrand.us/solutions/smart-lighting/radio-frequency-lighting-controls)
* [Legrand Developer Documentation: RFLC API for LC7001](https://developer.legrand.com/documentation/rflc-api-for-lc7001/)
